pub struct GlyphId(pub u32);Expand description
Represents a glyph identifier for a particular font. This identifier will not necessarily correspond to the correct glyph in a font other than the one that it was obtained from.
Tuple Fields
0: u32Trait Implementations
Sourceimpl IntoGlyphId for GlyphId
impl IntoGlyphId for GlyphId
Sourcefn into_glyph_id(self, _font: &Font<'_>) -> GlyphId
fn into_glyph_id(self, _font: &Font<'_>) -> GlyphId
Convert
self into a GlyphId, consulting the index map of font if
necessary.Sourceimpl Ord for GlyphId
impl Ord for GlyphId
Sourceimpl PartialOrd for GlyphId
impl PartialOrd for GlyphId
impl Copy for GlyphId
impl Eq for GlyphId
impl StructuralPartialEq for GlyphId