pub struct Section {
pub radians: Scalar,
pub offset_radians: Scalar,
}Expand description
A section of the oval will be drawn where the section is specified by the given radians.
A section with radians of 2.0 * PI would be equivalent to the full Oval.
Fields
radians: ScalarThe angle occuppied by the section’s circumference.
offset_radians: ScalarThe radians at which the section will begin.
A value of 0.0 will begin at the right of the oval.